@@ -43,6 +43,12 @@ def ConvNd(
     output_padding: Optional[int] = None,
     dtype=None,
 ):
+    # Only set `data_format` on the GPU: there is no CPU support.
+    if len(tf.config.list_physical_devices("GPU")) > 0:
+        data_format = "channels_first"
+    else:
+        data_format = "channels_last"
+
     # Only set `output_padding` if it is given.
     additional_args = {}
     if output_padding is not None:
@@ -54,12 +60,6 @@ def ConvNd(
     else:
         suffix = ""
 
-    # Only set `data_format` on the GPU: there is no CPU support.
-    if len(tf.config.list_physical_devices("GPU")) > 0:
-        data_format = "channels_first"
-    else:
-        data_format = "channels_last"
-
     conv_layer = getattr(tf.keras.layers, f"Conv{dim}D{suffix}")(
         input_shape=(in_channels,) + (None,) * dim,
         filters=out_channels,
@@ -85,6 +85,52 @@ def ConvNd(
         )
 
 
+def UpSamplingNd(
+    dim: int,
+    size: int = 2,
+    interp_method: str = "nearest",
+    dtype=None,
+):
+    # Only set `data_format` on the GPU: there is no CPU support. Moreover,
+    # `UpSampling1D` does not accept the keyword argument `data_format`.
+    if len(tf.config.list_physical_devices("GPU")) > 0 and dim > 1:
+        data_format = "channels_first"
+    else:
+        data_format = "channels_last"
+
+    # Due to inconsistent input signatures between TensorFlow's `UpSamplingND`
+    # classes, we must construct keyword arguments dependent on the input dimension.
+    additional_args = {}
+    if dim > 1:
+        # `UpSampling1D` does not accept the keyword `data_format` and requires data as
+        # channels last.
+        additional_args["data_format"] = data_format
+    if dim == 2:
+        # Only `UpSampling2D` accepts the `interpolation` keyword argument; the 1D and
+        # 3D classes only supports nearest-neighbour interpolation.
+        additional_args["interpolation"] = interp_method
+    elif interp_method != "nearest":
+        raise ValueError(
+            f'With {dim}D inputs, only "nearest" is supported for `interp_method`.'
+        )
+
+    upsample_layer = getattr(tf.keras.layers, f"UpSampling{dim}D")(
+        size=size if dim == 1 else (size,) * dim,
+        dtype=dtype,
+        **additional_args,
+    )
+    if data_format == "channels_first":
+        return upsample_layer
+    else:
+        return tf.keras.Sequential(
+            [
+                ChannelsToLast(dtype=dtype),
+                upsample_layer,
+                ChannelsToFirst(dtype=dtype),
+            ]
+        )
+
+
 def AvgPoolNd(
     dim: int,
     kernel: int,
@@ -137,6 +183,10 @@ class Interface:
     Conv2d = partial(ConvNd, dim=2)
     Conv3d = partial(ConvNd, dim=3)
 
+    UpSampling1d = partial(UpSamplingNd, dim=1)
+    UpSampling2d = partial(UpSamplingNd, dim=2)
+    UpSampling3d = partial(UpSamplingNd, dim=3)
+
     ConvTransposed1d = partial(ConvNd, dim=1, transposed=True)
     ConvTransposed2d = partial(ConvNd, dim=2, transposed=True)
     ConvTransposed3d = partial(ConvNd, dim=3, transposed=True)
